@@ -5,9 +5,10 @@ DM1_PVBASE = "BL22B-OP-ALPAO-01"  # Deformable mirror 1
 DM2_PVBASE = "BL22B-OP-ALPAO-02"  # Deformable mirror 2
 
 
-AD_ARRAY_COUNTER = "CAM:ArrayCounter_RBV"  # Frame counter
+AD_ARRAY_COUNTER = "ARR:UniqueId_RBV"  # Frame counter
 AD_ACQUIRE = "CAM:Acquire"  # Acquire button - write with 'Acquire'
 AD_GAIN = "CAM:Gain_RBV"  # Gain set on Windows app
+AD_SHUTTER_STATE = "CAM:SHUTTER_RBV"
 AD_ARRAY_DATA = "ARR:ArrayData"  # Data
 AD_DIM_X = "ARR:ArraySize0_RBV"
 AD_DIM_Y = "ARR:ArraySize1_RBV"
